``flask_admin.contrib.pymongo``
===============================

PyMongo model backend implementation.

.. automodule:: flask_admin.contrib.pymongo

    .. autoclass:: ModelView
        :members:
        :inherited-members:
        :exclude-members: column_filters

		Class inherits configuration options from :class:`~flask_admin.model.BaseModelView` and they're not displayed here.

        .. autoattribute:: column_filters
